Revision: 1228
Author: christian.wuerker
Date: Thu May 28 07:05:53 2015 UTC
Log: Updated classes after restructuring.
https://code.google.com/p/cmclasses/source/detail?r=1228
Added:
/branches/0.8.1/src/FS/Autoloader
Deleted:
/branches/0.8.1/src/LibCallCounter.php
Modified:
/branches/0.8.1/src/ADT/VCard.php
/branches/0.8.1/src/Alg/ID.php
/branches/0.8.1/src/Alg/Math/Algebra/GaussElimination.php
/branches/0.8.1/src/Alg/Math/Algebra/LabelMatrix.php
/branches/0.8.1/src/Alg/Math/Algebra/Matrix.php
/branches/0.8.1/src/Alg/Math/Algebra/Vector/CrossProduct.php
/branches/0.8.1/src/Alg/Math/Algebra/Vector/ScalarProduct.php
/branches/0.8.1/src/Alg/Math/Algebra/Vector.php
/branches/0.8.1/src/Alg/Math/Analysis/BinomialCoefficient.php
/branches/0.8.1/src/Alg/Math/Analysis/Bisection.php
/branches/0.8.1/src/Alg/Math/Analysis/Integration/Simpson.php
/branches/0.8.1/src/Alg/Math/Analysis/Integration/Trapezoid.php
/branches/0.8.1/src/Alg/Math/Analysis/Integration.php
/branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Lagrange.php
/branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Neville.php
/branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Newton.php
/branches/0.8.1/src/Alg/Math/Analysis/Interpolation/RegulaFalsi.php
/branches/0.8.1/src/Alg/Math/Analysis/Progression.php
/branches/0.8.1/src/Alg/Math/Analysis/RealBinomialCoefficient.php
/branches/0.8.1/src/Alg/Math/Analysis/Sequence.php
/branches/0.8.1/src/Alg/Math/Average.php
/branches/0.8.1/src/Alg/Math/CompactInterval.php
/branches/0.8.1/src/Alg/Math/ComplexNumber.php
/branches/0.8.1/src/Alg/Math/Euklid.php
/branches/0.8.1/src/Alg/Math/Extrapolation.php
/branches/0.8.1/src/Alg/Math/Factorial.php
/branches/0.8.1/src/Alg/Math/Finance/CompoundInterest.php
/branches/0.8.1/src/Alg/Math/Formula.php
/branches/0.8.1/src/Alg/Math/FormulaProduct.php
/branches/0.8.1/src/Alg/Math/FormulaSum.php
/branches/0.8.1/src/Alg/Math/Geometry/Circle.php
/branches/0.8.1/src/Alg/Math/Geometry/Point.php
/branches/0.8.1/src/Alg/Math/Geometry/Rectangle.php
/branches/0.8.1/src/Alg/Math/Geometry/Square.php
/branches/0.8.1/src/Alg/Math/Geometry/Triangle.php
/branches/0.8.1/src/Alg/Math/NaturalNumbers.php
/branches/0.8.1/src/Alg/Math/Polynomial.php
/branches/0.8.1/src/Alg/Math/Prime.php
/branches/0.8.1/src/Alg/Math/RationalNumbers.php
/branches/0.8.1/src/Alg/Math/RomanNumbers.php
/branches/0.8.1/src/Alg/Text/TermExtractor.php
/branches/0.8.1/src/Alg/Tree/Menu/Converter.php
/branches/0.8.1/src/Alg/UnusedVariableFinder.php
/branches/0.8.1/src/CLI/Application.php
/branches/0.8.1/src/CLI/ArgumentParser.php
/branches/0.8.1/src/CLI/Command/ArgumentParser.php
/branches/0.8.1/src/CLI/Command/Program.php
/branches/0.8.1/src/CLI/Downloader.php
/branches/0.8.1/src/CLI/Fork/Abstract.php
/branches/0.8.1/src/CLI/Fork/Server/Abstract.php
/branches/0.8.1/src/CLI/Fork/Server/Client/Abstract.php
/branches/0.8.1/src/CLI/Fork/Server/Client/WebProxy.php
/branches/0.8.1/src/CLI/Fork/Server/Dynamic.php
/branches/0.8.1/src/CLI/Fork/Server/Exception.php
/branches/0.8.1/src/CLI/Fork/Server/Reflect.php
/branches/0.8.1/src/CLI/Fork/Worker/Abstract.php
/branches/0.8.1/src/CLI/Output.php
/branches/0.8.1/src/CLI/Prompt.php
/branches/0.8.1/src/CLI/RequestReceiver.php
/branches/0.8.1/src/CLI/Server/Cron/Daemon.php
/branches/0.8.1/src/CLI/Server/Cron/Job.php
/branches/0.8.1/src/CLI/Server/Cron/Parser.php
/branches/0.8.1/src/CLI/Server/Daemon.php
/branches/0.8.1/src/CLI/Shell.php
/branches/0.8.1/src/DB/BaseConnection.php
/branches/0.8.1/src/DB/MSSQL/Connection.php
/branches/0.8.1/src/DB/MySQL/Connection.php
/branches/0.8.1/src/DB/MySQL/LazyConnection.php
/branches/0.8.1/src/DB/PDO/Connection.php
/branches/0.8.1/src/DB/PDO/DataSourceName.php
/branches/0.8.1/src/DB/PDO/TableReader.php
/branches/0.8.1/src/DB/PDO/TableWriter.php
/branches/0.8.1/src/DB/PgSQL/Connection.php
/branches/0.8.1/src/DB/Result.php
/branches/0.8.1/src/DB/Row.php
/branches/0.8.1/src/DB/StatementBuilder.php
/branches/0.8.1/src/DB/StatementCollection.php
/branches/0.8.1/src/DB/TableReader.php
/branches/0.8.1/src/DB/TableWriter.php
/branches/0.8.1/src/FS/File/Arc/Bzip.php
/branches/0.8.1/src/FS/File/Arc/Gzip.php
/branches/0.8.1/src/FS/File/Arc/Tar.php
/branches/0.8.1/src/FS/File/Arc/TarBzip.php
/branches/0.8.1/src/FS/File/Arc/TarGzip.php
/branches/0.8.1/src/FS/File/Backup.php
/branches/0.8.1/src/FS/File/BackupCleaner.php
/branches/0.8.1/src/FS/File/Block/Reader.php
/branches/0.8.1/src/FS/File/Block/Writer.php
/branches/0.8.1/src/FS/File/CSS/Combiner.php
/branches/0.8.1/src/FS/File/CSS/Compressor.php
/branches/0.8.1/src/FS/File/CSS/Converter.php
/branches/0.8.1/src/FS/File/CSS/Editor.php
/branches/0.8.1/src/FS/File/CSS/Parser.php
/branches/0.8.1/src/FS/File/CSS/Reader.php
/branches/0.8.1/src/FS/File/CSS/Relocator.php
/branches/0.8.1/src/FS/File/CSS/Theme/Combiner.php
/branches/0.8.1/src/FS/File/CSS/Theme/Finder.php
/branches/0.8.1/src/FS/File/CSS/Theme/Minimizer.php
/branches/0.8.1/src/FS/File/CSS/Writer.php
/branches/0.8.1/src/FS/File/CSV/Iterator.php
/branches/0.8.1/src/FS/File/CSV/IteratorReader.php
/branches/0.8.1/src/FS/File/CSV/Reader.php
/branches/0.8.1/src/FS/File/CSV/Writer.php
/branches/0.8.1/src/FS/File/Cache.php
/branches/0.8.1/src/FS/File/CodeLineCounter.php
/branches/0.8.1/src/FS/File/Configuration/Converter.php
/branches/0.8.1/src/FS/File/Configuration/Reader.php
/branches/0.8.1/src/FS/File/Editor.php
/branches/0.8.1/src/FS/File/Gantt/CalendarBuilder.php
/branches/0.8.1/src/FS/File/Gantt/MeetingCollector.php
/branches/0.8.1/src/FS/File/Gantt/MeetingReader.php
/branches/0.8.1/src/FS/File/ICal/Builder.php
/branches/0.8.1/src/FS/File/ICal/Parser.php
/branches/0.8.1/src/FS/File/INI/Creator.php
/branches/0.8.1/src/FS/File/INI/Editor.php
/branches/0.8.1/src/FS/File/INI/Reader.php
/branches/0.8.1/src/FS/File/INI/SectionEditor.php
/branches/0.8.1/src/FS/File/INI/SectionReader.php
/branches/0.8.1/src/FS/File/INI.php
/branches/0.8.1/src/FS/File/Iterator.php
/branches/0.8.1/src/FS/File/JSON/Config.php
/branches/0.8.1/src/FS/File/JSON/Reader.php
/branches/0.8.1/src/FS/File/JSON/Writer.php
/branches/0.8.1/src/FS/File/List/Editor.php
/branches/0.8.1/src/FS/File/List/Reader.php
/branches/0.8.1/src/FS/File/List/SectionReader.php
/branches/0.8.1/src/FS/File/List/SectionWriter.php
/branches/0.8.1/src/FS/File/List/Writer.php
/branches/0.8.1/src/FS/File/Log/JSON/Reader.php
/branches/0.8.1/src/FS/File/Log/JSON/Writer.php
/branches/0.8.1/src/FS/File/Log/Reader.php
/branches/0.8.1/src/FS/File/Log/ShortReader.php
/branches/0.8.1/src/FS/File/Log/ShortWriter.php
/branches/0.8.1/src/FS/File/Log/Tracker/Reader.php
/branches/0.8.1/src/FS/File/Log/Tracker/ShortReader.php
/branches/0.8.1/src/FS/File/Log/Writer.php
/branches/0.8.1/src/FS/File/NameFilter.php
/branches/0.8.1/src/FS/File/PHP/Check/MethodOrder.php
/branches/0.8.1/src/FS/File/PHP/Check/MethodVisibility.php
/branches/0.8.1/src/FS/File/PHP/Encoder.php
/branches/0.8.1/src/FS/File/PHP/Lister.php
/branches/0.8.1/src/FS/File/PHP/Parser/Array.php
/branches/0.8.1/src/FS/File/PHP/Parser/Doc/Decorator.php
/branches/0.8.1/src/FS/File/PHP/Parser/Doc/Regular.php
/branches/0.8.1/src/FS/File/PHP/Parser/Reflection.php
/branches/0.8.1/src/FS/File/PHP/Parser/Regular.php
/branches/0.8.1/src/FS/File/PHP/Test/Creator.php
/branches/0.8.1/src/FS/File/Permissions.php
/branches/0.8.1/src/FS/File/Reader.php
/branches/0.8.1/src/FS/File/RecursiveIterator.php
/branches/0.8.1/src/FS/File/RecursiveNameFilter.php
/branches/0.8.1/src/FS/File/RecursiveRegexFilter.php
/branches/0.8.1/src/FS/File/RecursiveTodoLister.php
/branches/0.8.1/src/FS/File/RegexFilter.php
/branches/0.8.1/src/FS/File/StaticCache.php
/branches/0.8.1/src/FS/File/SyntaxChecker.php
/branches/0.8.1/src/FS/File/TodoLister.php
/branches/0.8.1/src/FS/File/Unicoder.php
/branches/0.8.1/src/FS/File/VCard/Builder.php
/branches/0.8.1/src/FS/File/VCard/Parser.php
/branches/0.8.1/src/FS/File/VCard/Reader.php
/branches/0.8.1/src/FS/File/VCard/Writer.php
/branches/0.8.1/src/FS/File/Wiki.php
/branches/0.8.1/src/FS/File/Writer.php
/branches/0.8.1/src/FS/File/YAML/Reader.php
/branches/0.8.1/src/FS/File/YAML/Spyc.php
/branches/0.8.1/src/FS/File/YAML/Writer.php
/branches/0.8.1/src/FS/Folder/CodeLineCounter.php
/branches/0.8.1/src/FS/Folder/Editor.php
/branches/0.8.1/src/FS/Folder/Iterator.php
/branches/0.8.1/src/FS/Folder/Lister.php
/branches/0.8.1/src/FS/Folder/MethodSortCheck.php
/branches/0.8.1/src/FS/Folder/MethodVisibilityCheck.php
/branches/0.8.1/src/FS/Folder/Reader.php
/branches/0.8.1/src/FS/Folder/RecursiveIterator.php
/branches/0.8.1/src/FS/Folder/RecursiveLister.php
/branches/0.8.1/src/FS/Folder/RecursiveRegexFilter.php
/branches/0.8.1/src/FS/Folder/RegexFilter.php
/branches/0.8.1/src/FS/Folder/ServiceNameSortCheck.php
/branches/0.8.1/src/FS/Folder/SyntaxChecker.php
/branches/0.8.1/src/FS/Folder/Treeview/Json.php
/branches/0.8.1/src/FS/Folder/Treeview/JsonExtended.php
/branches/0.8.1/src/Net/API/Dyn.php
/branches/0.8.1/src/Net/API/Google/Maps/Geocoder.php
/branches/0.8.1/src/Net/AtomServerTime.php
/branches/0.8.1/src/Net/Service/Definition/Converter.php
/branches/0.8.1/src/Net/Service/Definition/Loader.php
/branches/0.8.1/src/Net/Service/Definition/XmlWriter.php
/branches/0.8.1/src/Net/Service/Response/TodoLister.php
/branches/0.8.1/src/Net/Site/MapCreator.php
/branches/0.8.1/src/Net/Site/MapWriter.php
/branches/0.8.1/src/UI/ClassParser.php
/branches/0.8.1/src/UI/HTML/Tree/FolderCheckView.php
/branches/0.8.1/src/UI/Image/Captcha.php
/branches/0.8.1/src/UI/Image/FormulaDiagram.php
/branches/0.8.1/src/UI/Image/Graphviz/Graph.php
/branches/0.8.1/src/UI/Image/Graphviz/Renderer.php
/branches/0.8.1/src/UI/SVG/Chart.php
/branches/0.8.1/src/XML/Atom/Reader.php
/branches/0.8.1/src/XML/DOM/FeedIdentifier.php
/branches/0.8.1/src/XML/DOM/FileReader.php
/branches/0.8.1/src/XML/DOM/FileWriter.php
/branches/0.8.1/src/XML/DOM/GoogleSitemapWriter.php
/branches/0.8.1/src/XML/DOM/ObjectFileDeserializer.php
/branches/0.8.1/src/XML/DOM/ObjectFileSerializer.php
/branches/0.8.1/src/XML/DOM/PEAR/PackageReader.php
/branches/0.8.1/src/XML/Element.php
/branches/0.8.1/src/XML/ElementReader.php
/branches/0.8.1/src/XML/FeedIdentifier.php
/branches/0.8.1/src/XML/OPML/FileReader.php
/branches/0.8.1/src/XML/OPML/FileWriter.php
/branches/0.8.1/src/XML/RSS/Reader.php
/branches/0.8.1/src/XML/RSS/SimpleReader.php
/branches/0.8.1/src/XML/RSS/Writer.php
/branches/0.8.1/src/XML/Validator.php
/branches/0.8.1/src/XML/WDDX/Configuration.php
/branches/0.8.1/src/XML/WDDX/FileReader.php
/branches/0.8.1/src/XML/WDDX/FileWriter.php
/branches/0.8.1/src/XML/XSL/Transformator.php
=======================================
--- /branches/0.8.1/src/LibCallCounter.php Sat May 23 06:45:51 2015 UTC
+++ /dev/null
@@ -1,92 +0,0 @@
-<?php
-class LibCallCounter
-{
- public static $classBlacklist = array(
- 'de.ceus-media.throwException',
- 'de.ceus-media.LibCallCounter',
- 'de.ceus-media.ui.DevOutput'
- );
- public static $classCalls = array();
- public static $logScheme = "compress.zlib://";
- public static $logFileName = "calls.json.gz";
-
- public static function closeCall()
- {
- $mode = defined( 'CM_CLASSES_CALL_LOG_MODE' ) ?
CM_CLASSES_CALL_LOG_MODE : 0;
- if( ( $mode & 1 ) !== 1 )
- return;
- $data = self::readData();
- $data[0]--;
- if( ( $mode & 2 ) == 2 )
- {
- $classList = array_keys( $GLOBALS['imported'] );
- $classList = array_diff( $classList, self::$classBlacklist );
- $key = $data[1]."-".time();
- if( $classList )
- $data[4][$key] = $classList;
- }
- self::writeData( $data );
- }
-
- public static function getRawData()
- {
- $data = self::readData();
- return $data;
- }
-
- public static function getCalls()
- {
- $data = self::readData();
- return $data[1];
- }
-
- protected static function getFileName()
- {
- return dirname( __FILE__)."/".self::$logFileName;
- }
-
- public static function getOpenCalls()
- {
- $data = self::readData();
- return $data[0];
- }
-
- public static function openCall()
- {
- $mode = defined( 'CM_CLASSES_CALL_LOG_MODE' ) ?
CM_CLASSES_CALL_LOG_MODE : 0;
- if( ( $mode & 1 ) !== 1 )
- return;
- $data = self::readData();
- $data[0]++; // increase number of paraller calls
- $data[1]++; // increase number of total calls
- self::writeData( $data ); // save new information
- }
-
- protected static function readData()
- {
- $fileName = self::getFileName();
- $data = array( 0, 0, time(), time(), array() );
- if( file_exists( $fileName ) )
- $data = json_decode( file_get_contents( self::$logScheme.$fileName ),
TRUE );
- return $data;
- }
-
- public static function setup()
- {
- self::openCall();
- register_shutdown_function(array('LibCallCounter','closeCall'));
- }
-
- protected static function writeData( $data )
- {
- $fileName = self::getFileName();
- return file_put_contents( self::$logScheme.$fileName, json_encode( $data
) );
- }
-
- protected static function report()
- {
-
-
- }
-}
-?>
=======================================
--- /branches/0.8.1/src/ADT/VCard.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/ADT/VCard.php Thu May 28 07:05:53 2015 UTC
@@ -32,7 +32,7 @@
* @category cmClasses
* @package ADT
* @implements Serializable
- * @uses File_VCard_Builder
+ * @uses FS_File_VCard_Builder
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -188,7 +188,7 @@
*/
public static function createFromString( $string )
{
- return File_VCard_Parser::parse( $string );
+ return FS_File_VCard_Parser::parse( $string );
}
/**
@@ -215,7 +215,7 @@
public function fromString( $string )
{
$this->__construct();
- File_VCard_Parser::parseInto( $string, $this );
+ FS_File_VCard_Parser::parseInto( $string, $this );
}
/**
@@ -475,7 +475,7 @@
*/
public function toString( $charsetIn = NULL, $charsetOut = NULL )
{
- return File_VCard_Builder::build( $this, $charsetIn, $charsetOut );
+ return FS_File_VCard_Builder::build( $this, $charsetIn, $charsetOut );
}
/**
=======================================
--- /branches/0.8.1/src/Alg/ID.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/ID.php Thu May 28 07:05:53 2015 UTC
@@ -1,6 +1,5 @@
<?php
class Alg_ID{
-
static public function uuid(){
if( function_exists( 'com_create_guid' ) === TRUE )
return trim( com_create_guid(), '{}' );
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/GaussElimination.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/GaussElimination.php Thu May 28
07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Implementation of Gauss Eleminiation Algorith with Pivot Search.
* @category cmClasses
* @package Math.Algebra
- * @uses Math_Algebra_Vector
+ * @uses Alg_Math_Algebra_Vector
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -38,7 +38,7 @@
* @since 18.01.2006
* @version $Id$
*/
-class Math_Algebra_GaussElimination
+class Alg_Math_Algebra_GaussElimination
{
/** @var int $accuracy Accuracy of calculation */
protected $accuracy;
@@ -57,7 +57,7 @@
/**
* Returns the advices Privot Row within a Matrix.
* @access protected
- * @param Math_Algebra_Matrix $matrix Matrix to eliminate
+ * @param Alg_Math_Algebra_Matrix $matrix Matrix to eliminate
* @param int $column current Column
* @param int $row Row to start Search
* @return int
@@ -80,8 +80,8 @@
/**
* Eliminates Matrix using Gauss Algorithm.
* @access public
- * @param Math_Algebra_Matrix $matrix Matrix to eliminate
- * @return Math_Algebra_Matrix
+ * @param Alg_Math_Algebra_Matrix $matrix Matrix to eliminate
+ * @return Alg_Math_Algebra_Matrix
*/
public function eliminate( $matrix )
{
@@ -107,8 +107,8 @@
/**
* Resolves eliminated Matrix and return Solution Vector.
* @access public
- * @param Math_Algebra_Matrix $matrix Matrix to eliminate
- * @return Math_Algebra_Vector
+ * @param Alg_Math_Algebra_Matrix $matrix Matrix to eliminate
+ * @return Alg_Math_Algebra_Vector
*/
public function resolve( $matrix )
{
@@ -136,7 +136,7 @@
}
}
ksort( $solution );
- $solution = new Math_Algebra_Vector( array_values( $solution ) );
+ $solution = new Alg_Math_Algebra_Vector( array_values( $solution ) );
return $solution;
}
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/LabelMatrix.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/LabelMatrix.php Thu May 28
07:05:53 2015 UTC
@@ -36,13 +36,13 @@
* @version $Id$
* @todo Code Doc
*/
-class Math_Algebra_LabelMatrix
+class Alg_Math_Algebra_LabelMatrix
{
public function __construct( $rows, $columns, $init = 0 )
{
$this->rows = $rows;
$this->columns = $columns;
- $this->matrix = new Math_Algebra_Matrix( count( $rows ), count( $columns
), $init );
+ $this->matrix = new Alg_Math_Algebra_Matrix( count( $rows ), count(
$columns ), $init );
}
public function __call( $method, $arguments )
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/Matrix.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/Matrix.php Thu May 28 07:05:53
2015 UTC
@@ -29,14 +29,14 @@
* Matrix.
* @category cmClasses
* @package Math.Algebra
- * @uses Math_Algebra_Vector
+ * @uses Alg_Math_Algebra_Vector
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Algebra_Matrix
+class Alg_Math_Algebra_Matrix
{
/** @var int $rowNumber Number of Rows */
protected $rowNumber = 0;
@@ -101,7 +101,7 @@
* Returns a column as Vector.
* @access public
* @param int $column Column Index
- * @return Math_Algebra_Vector
+ * @return Alg_Math_Algebra_Vector
*/
public function getColumn( $column )
{
@@ -110,20 +110,20 @@
$values = array();
for( $row = 0; $row < $this->getRowNumber(); $row++ )
$values[] = $this->getValue( $row, $column );
- return new Math_Algebra_Vector( $values );
+ return new Alg_Math_Algebra_Vector( $values );
}
/**
* Returns a row as Vector.
* @access public
* @param int $row Row Index
- * @return Math_Algebra_Vector
+ * @return Alg_Math_Algebra_Vector
*/
public function getRow( $row )
{
if( $row < 0 || $row >= $this->getRowNumber() )
throw new OutOfRangeException( 'Row key "'.$row.'" is not valid.' );
- return new Math_Algebra_Vector( $this->values[$row] );
+ return new Alg_Math_Algebra_Vector( $this->values[$row] );
}
/**
@@ -162,7 +162,7 @@
/**
* Returns transposed Matrix.
* @access public
- * @return Math_Algebra_Matrix
+ * @return Alg_Math_Algebra_Matrix
*/
public function transpose()
{
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/Vector/CrossProduct.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/Vector/CrossProduct.php Thu May 28
07:05:53 2015 UTC
@@ -29,21 +29,21 @@
* Cross Product of two Vectors with 3 Dimensions.
* @category cmClasses
* @package Math.Algebra.Vector
- * @uses Math_Algebra_Vector
+ * @uses Alg_Math_Algebra_Vector
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Algebra_Vector_CrossProduct
+class Alg_Math_Algebra_Vector_CrossProduct
{
/**
* Returns Cross Product of two Vectors
* @access public
- * @param Math_Algebra_Vector $vector1 Vector 1
- * @param Math_Algebra_Vector $vector2 Vector 2
- * @return Math_Algebra_Vector
+ * @param Alg_Math_Algebra_Vector $vector1 Vector 1
+ * @param Alg_Math_Algebra_Vector $vector2 Vector 2
+ * @return Alg_Math_Algebra_Vector
*/
public function produce( $vector1, $vector2 )
{
@@ -54,7 +54,7 @@
$x = $vector1->getValueFromIndex( 1 ) * $vector2->getValueFromIndex( 2
) - $vector1->getValueFromIndex( 2 ) * $vector2->getValueFromIndex( 1 );
$y = $vector1->getValueFromIndex( 2 ) * $vector2->getValueFromIndex( 0
) - $vector1->getValueFromIndex( 0 ) * $vector2->getValueFromIndex( 2 );
$z = $vector1->getValueFromIndex( 0 ) * $vector2->getValueFromIndex( 1
) - $vector1->getValueFromIndex( 1 ) * $vector2->getValueFromIndex( 0 );
- $c = new Math_Algebra_Vector( $x, $y, $z );
+ $c = new Alg_Math_Algebra_Vector( $x, $y, $z );
}
return $c;
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/Vector/ScalarProduct.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/Vector/ScalarProduct.php Thu May
28 07:05:53 2015 UTC
@@ -35,13 +35,13 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Algebra_Vector_ScalarProduct
+class Alg_Math_Algebra_Vector_ScalarProduct
{
/**
* Returns Scalar Product of two Vectors
* @access public
- * @param Math_Algebra_Vector $vector1 Vector 1
- * @param Math_Algebra_Vector $vector2 Vector 2
+ * @param Alg_Math_Algebra_Vector $vector1 Vector 1
+ * @param Alg_Math_Algebra_Vector $vector2 Vector 2
* @return mixed
*/
public function produce( $vector1, $vector2 )
=======================================
--- /branches/0.8.1/src/Alg/Math/Algebra/Vector.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Algebra/Vector.php Thu May 28 07:05:53
2015 UTC
@@ -35,7 +35,7 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Algebra_Vector
+class Alg_Math_Algebra_Vector
{
/** @var int $dimension Dimension of the Vector */
protected $dimension = 0;
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/BinomialCoefficient.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/BinomialCoefficient.php Thu May
28 07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Calculation of Factorial for Integers.
* @category cmClasses
* @package Math.Analysis
- * @uses Math_Factorial
+ * @uses Alg_Math_Factorial
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -38,7 +38,7 @@
* @since 24.04.2006
* @version $Id$
*/
-class Math_Analysis_BinomialCoefficient
+class Alg_Math_Analysis_BinomialCoefficient
{
/**
* Calculates Binomial Coefficient of Top and Button Integers.
@@ -57,7 +57,7 @@
throw new InvalidArgumentException( 'Bottom Number must be an Integer.'
);
else
{
- $result = Math_Factorial::calculate( $top ) / (
Math_Factorial::calculate( $bottom ) * Math_Factorial::calculate( $top -
$bottom ) );
+ $result = Alg_Math_Factorial::calculate( $top ) / (
Alg_Math_Factorial::calculate( $bottom ) * Alg_Math_Factorial::calculate(
$top - $bottom ) );
return $result;
}
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Bisection.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Bisection.php Thu May 28 07:05:53
2015 UTC
@@ -30,8 +30,8 @@
* Bisection Interpolation within a compact Interval.
* @category cmClasses
* @package Math.Analysis
- * @uses Math_Formula
- * @uses Math_CompactInterval
+ * @uses Alg_Math_Formula
+ * @uses Alg_Math_CompactInterval
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -39,9 +39,9 @@
* @since 03.02.2006
* @version $Id$
*/
-class Math_Analysis_Bisection
+class Alg_Math_Analysis_Bisection
{
- /** @var Math_Formula $formula Formula Object */
+ /** @var Alg_Math_Formula $formula Formula Object */
protected $formula = array();
/**
@@ -53,7 +53,7 @@
*/
public function setFormula( $formula, $vars )
{
- $this->formula = new Math_Formula( $formula, array( $vars ) );
+ $this->formula = new Alg_Math_Formula( $formula, array( $vars ) );
}
/**
@@ -65,7 +65,7 @@
*/
public function setInterval( $start, $end )
{
- $this->interval = new Math_CompactInterval( $start, $end );
+ $this->interval = new Alg_Math_CompactInterval( $start, $end );
}
/**
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Integration/Simpson.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Integration/Simpson.php Thu May
28 07:05:53 2015 UTC
@@ -29,14 +29,14 @@
* Integration with Simpsons Algorithm within a compact Interval.
* @category cmClasses
* @package Math.Analysis.Integration
- * @extends Math_Analysis_Integration
+ * @extends Alg_Math_Analysis_Integration
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Analysis_Integration_Simpson extends Math_Analysis_Integration
+class Alg_Math_Analysis_Integration_Simpson extends
Alg_Math_Analysis_Integration
{
/**
* Calculates integrational sum of Formula within the Interval by using
Sampling Nodes.
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Integration/Trapezoid.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Integration/Trapezoid.php Thu May
28 07:05:53 2015 UTC
@@ -29,14 +29,14 @@
* Integration with Trapezoid Algorithm within a compact Interval.
* @category cmClasses
* @package Math.Analysis.Integration
- * @extends Math_Analysis_Integration
+ * @extends Alg_Math_Analysis_Integration
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Analysis_Integration_Trapezoid extends Math_Analysis_Integration
+class Alg_Math_Analysis_Integration_Trapezoid extends
Alg_Math_Analysis_Integration
{
/**
* Calculates integrational sum of Formula within the Interval by using
Sampling Nodes.
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Integration.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Integration.php Thu May 28
07:05:53 2015 UTC
@@ -35,11 +35,11 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Analysis_Integration
+class Alg_Math_Analysis_Integration
{
- /** @var Math_Formula $formula Formula to integrate */
+ /** @var Alg_Math_Formula $formula Formula to integrate */
protected $formula;
- /** @var Math_CompactInterval $interval Interval to integrate within */
+ /** @var Alg_Math_CompactInterval $interval Interval to integrate
within */
protected $interval;
/** @var int $nodes Amount of Sampling Nodes to use */
protected $nodes;
@@ -47,8 +47,8 @@
/**
* Constructor.
* @access public
- * @param Math_Formula $formula Formula to integrate
- * @param Math_CompactInterval $interval Interval to integrate within
+ * @param Alg_Math_Formula $formula Formula to integrate
+ * @param Alg_Math_CompactInterval $interval Interval to integrate
within
* @param int $nodes Amount of Sampling Nodes to use
* @return void
*/
@@ -62,7 +62,7 @@
/**
* Returns set Formula.
* @access public
- * @return Math_Formula
+ * @return Alg_Math_Formula
*/
public function getFormula()
{
@@ -72,7 +72,7 @@
/**
* Returns set Interval.
* @access public
- * @return Math_CompactInterval
+ * @return Alg_Math_CompactInterval
*/
public function getInterval()
{
@@ -82,7 +82,7 @@
/**
* Returns quantity of Sampling Nodes.
* @access public
- * @return Math_Formula
+ * @return Alg_Math_Formula
*/
public function getNodes()
{
@@ -141,7 +141,7 @@
/**
* Sets Formula.
* @access public
- * @param Math_Formula $formula Formula to integrate
+ * @param Alg_Math_Formula $formula Formula to integrate
* @return void
*/
public function setFormula( $formula )
@@ -152,7 +152,7 @@
/**
* Sets Interval.
* @access public
- * @param Math_CompactInterval $interval Interval to integrate within
+ * @param Alg_Math_CompactInterval $interval Interval to integrate
within
* @return void
*/
public function setInterval( $interval )
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Lagrange.php Sat
May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Lagrange.php Thu
May 28 07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Lagrange Interpolation.
* @category cmClasses
* @package Math.Analysis.Interpolation
- * @uses Math_Formula
+ * @uses Alg_Math_Formula
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -38,7 +38,7 @@
* @since 03.02.2006
* @version $Id$
*/
-class Math_Analysis_Interpolation_Lagrange
+class Alg_Math_Analysis_Interpolation_Lagrange
{
/** @var array $data Array of x and y values (Xi->Fi) */
protected $data = array();
@@ -106,7 +106,7 @@
for( $i=0; $i<count( $expressions ); $i++ )
{
$expression = $expressions[$i];
- $formula = new Math_Formula( $expression, array( "x" ) );
+ $formula = new Alg_Math_Formula( $expression, array( "x" ) );
$value = $formula->getValue( 2 );
$sum += $values[$i] * $value;
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Neville.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Neville.php Thu May
28 07:05:53 2015 UTC
@@ -37,7 +37,7 @@
* @since 03.02.2006
* @version $Id$
*/
-class Math_Analysis_Interpolation_Neville
+class Alg_Math_Analysis_Interpolation_Neville
{
/** @var array $data Array of x and y values (Xi->Fi) */
protected $data = array();
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Newton.php Sat May
23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/Newton.php Thu May
28 07:05:53 2015 UTC
@@ -37,7 +37,7 @@
* @since 03.02.2006
* @version $Id$
*/
-class Math_Analysis_Interpolation_Newton
+class Alg_Math_Analysis_Interpolation_Newton
{
/** @var array $data Array of x and y values (Xi->Fi) */
protected $data = array();
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/RegulaFalsi.php Sat
May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Interpolation/RegulaFalsi.php Thu
May 28 07:05:53 2015 UTC
@@ -30,8 +30,8 @@
* RegulaFalsi Interpolation within a compact Interval.
* @category cmClasses
* @package Math.Analysis.Interpolation
- * @uses Math_Formula
- * @uses Math_CompactInterval
+ * @uses Alg_Math_Formula
+ * @uses Alg_Math_CompactInterval
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -39,13 +39,13 @@
* @since 03.02.2006
* @version $Id$
*/
-class Math_Analysis_Interpolation_RegulaFalsi
+class Alg_Math_Analysis_Interpolation_RegulaFalsi
{
/** @var array $data Array of x and y values (Xi->Fi) */
protected $data = array();
- /** @var Math_Formula $formula Formula */
+ /** @var Alg_Math_Formula $formula Formula */
protected $formula;
- /** @var Math_CompactInterval $interval Interval */
+ /** @var Alg_Math_CompactInterval $interval Interval */
protected $interval;
/**
@@ -88,7 +88,7 @@
*/
public function setFormula( $formula, $variables )
{
- $this->formula = new Math_Formula( $formula, $variables );
+ $this->formula = new Alg_Math_Formula( $formula, $variables );
}
/**
@@ -102,7 +102,7 @@
{
if( $start * $end > 0 )
throw new InvalidArgumentException( 'Interval needs to start below 0.'
);
- $this->interval = new Math_CompactInterval( $start, $end );
+ $this->interval = new Alg_Math_CompactInterval( $start, $end );
}
}
?>
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Progression.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Progression.php Thu May 28
07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Progression within a compact Interval.
* @category cmClasses
* @package Math.Analysis
- * @extends Math_Analysis_Sequence
+ * @extends Alg_Math_Analysis_Sequence
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -39,13 +39,13 @@
* @version $Id$
* @todo Code Correction
*/
-class Math_Analysis_Progression extends Math_Analysis_Sequence
+class Alg_Math_Analysis_Progression extends Alg_Math_Analysis_Sequence
{
/**
* Constructor.
* @access public
- * @param Math_Formula $formula Formula of Progression
- * @param Math_CompactInterval $interval Interval of Progression
+ * @param Alg_Math_Formula $formula Formula of Progression
+ * @param Alg_Math_CompactInterval $interval Interval of Progression
* @return void
*/
public function __construct( $formula, $interval )
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/RealBinomialCoefficient.php Sat
May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/RealBinomialCoefficient.php Thu
May 28 07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Calculation of Factorial for Reals.
* @category cmClasses
* @package Math.Analysis
- * @uses Math_Factorial
+ * @uses Alg_Math_Factorial
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -38,7 +38,7 @@
* @since 24.04.2006
* @version $Id$
*/
-class Math_Analysis_RealBinomialCoefficient
+class Alg_Math_Analysis_RealBinomialCoefficient
{
/**
* Calculates Binomial Coefficient of Top and Button Integers.
@@ -59,7 +59,7 @@
$product = 1;
for( $i=0; $i<$bottom; $i++ )
$product *= $top - $i;
- $result = $product / Math_Factorial::calculate( $bottom );
+ $result = $product / Alg_Math_Factorial::calculate( $bottom );
return $result;
}
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Analysis/Sequence.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Analysis/Sequence.php Thu May 28 07:05:53
2015 UTC
@@ -35,18 +35,18 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Analysis_Sequence
+class Alg_Math_Analysis_Sequence
{
- /** @var Math_Formula $formula Formula to integrate */
+ /** @var Alg_Math_Formula $formula Formula to integrate */
protected $formula;
- /** @var Math_CompactInterval $interval Interval to integrate within */
+ /** @var Alg_Math_CompactInterval $interval Interval to integrate
within */
protected $interval;
/**
* Constructor.
* @access public
- * @param Math_Formula $formula Formula of Sequence
- * @param Math_CompactInterval $interval Interval of Sequence
+ * @param Alg_Math_Formula $formula Formula of Sequence
+ * @param Alg_Math_CompactInterval $interval Interval of Sequence
* @return void
*/
public function __construct( $formula, $interval )
=======================================
--- /branches/0.8.1/src/Alg/Math/Average.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Average.php Thu May 28 07:05:53 2015 UTC
@@ -38,7 +38,7 @@
* @version $Id$
* @todo finish Implementation
*/
-class Math_Average
+class Alg_Math_Average
{
/**
* Calculates artithmetic Average.
=======================================
--- /branches/0.8.1/src/Alg/Math/CompactInterval.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/CompactInterval.php Thu May 28 07:05:53
2015 UTC
@@ -35,7 +35,7 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_CompactInterval
+class Alg_Math_CompactInterval
{
/** @var mixed $end End of Interval */
protected $end;
=======================================
--- /branches/0.8.1/src/Alg/Math/ComplexNumber.php Sat May 23 06:45:51 2015
UTC
+++ /branches/0.8.1/src/Alg/Math/ComplexNumber.php Thu May 28 07:05:53 2015
UTC
@@ -37,7 +37,7 @@
* @since 22.06.2005
* @version $Id$
*/
-class Math_ComplexNumber
+class Alg_Math_ComplexNumber
{
/** @var int $real Real part of the complex number */
protected $real;
=======================================
--- /branches/0.8.1/src/Alg/Math/Euklid.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Euklid.php Thu May 28 07:05:53 2015 UTC
@@ -40,7 +40,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Euklid
+class Alg_Math_Euklid
{
/**
* ggT( m, n)
=======================================
--- /branches/0.8.1/src/Alg/Math/Extrapolation.php Sat May 23 06:45:51 2015
UTC
+++ /branches/0.8.1/src/Alg/Math/Extrapolation.php Thu May 28 07:05:53 2015
UTC
@@ -39,7 +39,7 @@
* @version $Id$
* @todo test
*/
-class Math_Extrapolation
+class Alg_Math_Extrapolation
{
/**
* Projects values into a sized container and returns list of range
objects.
=======================================
--- /branches/0.8.1/src/Alg/Math/Factorial.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Factorial.php Thu May 28 07:05:53 2015 UTC
@@ -37,7 +37,7 @@
* @since 24.04.2006
* @version $Id$
*/
-class Math_Factorial
+class Alg_Math_Factorial
{
/**
* Calculates Factorial of Integer recursive and returns Integer or
Double.
=======================================
--- /branches/0.8.1/src/Alg/Math/Finance/CompoundInterest.php Sat May 23
06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Finance/CompoundInterest.php Thu May 28
07:05:53 2015 UTC
@@ -37,7 +37,7 @@
* @since 19.12.2007
* @version $Id$
*/
-class Math_Finance_CompoundInterest
+class Alg_Math_Finance_CompoundInterest
{
/** @var float $amount Amount to calculate with */
protected $amount;
=======================================
--- /branches/0.8.1/src/Alg/Math/Polynomial.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Polynomial.php Thu May 28 07:05:53 2015 UTC
@@ -29,14 +29,14 @@
* Polynomial.
* @category cmClasses
* @package Math
- * @uses Math_Formula
+ * @uses Alg_Math_Formula
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Polynomial
+class Alg_Math_Polynomial
{
/** @var array $_coefficients Array of coefficients starting with
highest potency */
protected $coefficients = array();
@@ -125,7 +125,7 @@
/**
* Returns Formula Object of Polynomial.
* @access public
- * @return Math_Formula
+ * @return Alg_Math_Formula
* @since 15.09.2006
*/
public function getFormula()
@@ -152,7 +152,7 @@
$expression .= $expression ? $sign.abs( $a ) : $a;
}
}
- $formula = new Math_Formula( $expression, "x" );
+ $formula = new Alg_Math_Formula( $expression, "x" );
return $formula;
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Prime.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Prime.php Thu May 28 07:05:53 2015 UTC
@@ -37,7 +37,7 @@
* @since 30.4.2005
* @version $Id$
*/
-class Math_Prime
+class Alg_Math_Prime
{
/**
* Returns all Primes from 2 to a given Number
=======================================
--- /branches/0.8.1/src/Alg/Math/RationalNumbers.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/RationalNumbers.php Thu May 28 07:05:53
2015 UTC
@@ -29,7 +29,7 @@
* ...
* @category cmClasses
* @package Math
- * @uses Math_NaturalNumbers
+ * @uses Alg_Math_NaturalNumbers
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -37,7 +37,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_RationNumbers
+class Alg_Math_RationNumbers
{
public static function inv( $float )
@@ -59,7 +59,7 @@
{
if( $deepth > 10 )
trigger_error( "no divisor found.", E_USER_ERROR );
- if( Math_NaturalNumbers::isNatural( $float ) )
+ if( Alg_Math_NaturalNumbers::isNatural( $float ) )
return 1;
else
{
@@ -67,7 +67,7 @@
$minor = (float) "0".".".$parts[1];
$factor = self::rec ($minor);
# echo "<br>[".$deepth."] minor: ".$minor." | factor: ".$factor;
- return $factor * self::leastDivisor($factor,
Math_NaturalNumbers::succ($deepth));
+ return $factor * self::leastDivisor($factor,
Alg_Math_NaturalNumbers::succ($deepth));
}
}
@@ -122,7 +122,7 @@
$max *= 10;
$shift++;
}
- if( $gcd = Math_NaturalNumbers::gcd( $sum, $max ) )
+ if( $gcd = Alg_Math_NaturalNumbers::gcd( $sum, $max ) )
{
# remark( "sum: ".$sum." max: ".$max. " -> gcd: ".$gcd );
$sum /= $gcd;
=======================================
--- /branches/0.8.1/src/Alg/Math/RomanNumbers.php Sat May 23 06:45:51 2015
UTC
+++ /branches/0.8.1/src/Alg/Math/RomanNumbers.php Thu May 28 07:05:53 2015
UTC
@@ -38,7 +38,7 @@
* @since 22.06.2005
* @version $Id$
*/
-class Math_RomanNumbers
+class Alg_Math_RomanNumbers
{
/** @var array $roman Map of roman numbers and shortcut placeholders*/
protected static $roman = array(
=======================================
--- /branches/0.8.1/src/Alg/Text/TermExtractor.php Sat May 23 06:45:51 2015
UTC
+++ /branches/0.8.1/src/Alg/Text/TermExtractor.php Thu May 28 07:05:53 2015
UTC
@@ -30,7 +30,7 @@
* Extracts Terms from a Text Document.
* @category cmClasses
* @package Alg.Text
- * @uses File_Editor
+ * @uses FS_File_Editor
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2009-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -83,13 +83,13 @@
public static function loadBlacklist( $fileName )
{
- $string = File_Editor::load( $fileName );
+ $string = FS_File_Editor::load( $fileName );
if( !Alg_Text_Unicoder::isUnicode( $string ) )
{
$string = Alg_Text_Unicoder::convertToUnicode( $string );
- File_Editor::save( $fileName, $string );
+ FS_File_Editor::save( $fileName, $string );
}
- $list = File_Editor::loadArray( $fileName );
+ $list = FS_File_Editor::loadArray( $fileName );
self::setBlacklist( array_unique( $list ) );
}
=======================================
--- /branches/0.8.1/src/Alg/Tree/Menu/Converter.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Tree/Menu/Converter.php Thu May 28 07:05:53
2015 UTC
@@ -30,7 +30,7 @@
* Converter between OPML and Tree Menu Structure.
* @category cmClasses
* @package Alg.Tree.Menu
- * @uses File_Reader
+ * @uses FS_File_Reader
* @uses XML_OPML_Parser
* @uses ADT_Tree_Menu_List
* @author Christian Würker <
christia...@ceusmedia.de>
@@ -53,7 +53,7 @@
*/
public static function convertFromOpmlFile( $fileName, $labelRoot,
$rootClass = NULL )
{
- $opml = File_Reader::load( $fileName );
+ $opml = FS_File_Reader::load( $fileName );
return self::convertFromOpml( $opml, $labelRoot, $rootClass );
}
=======================================
--- /branches/0.8.1/src/Alg/UnusedVariableFinder.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/UnusedVariableFinder.php Thu May 28 07:05:53
2015 UTC
@@ -225,7 +225,7 @@
*/
public function readFile( $fileName )
{
- $code = File_Reader::load( $fileName );
+ $code = FS_File_Reader::load( $fileName );
$this->readCode( $code );
}
}
=======================================
--- /branches/0.8.1/src/CLI/Application.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/CLI/Application.php Thu May 28 07:05:53 2015 UTC
@@ -30,7 +30,7 @@
* Generic Console Application.
* @category cmClasses
* @package Console
- * @extends Console_ArgumentParser
+ * @extends CLI_ArgumentParser
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -38,7 +38,7 @@
* @since 11.01.2006
* @version $Id$
*/
-class Console_Application
+class CLI_Application
{
/**
* Constructor.
@@ -48,7 +48,7 @@
*/
public function __construct( $shortcuts = array(), $fallBackOnEmptyPair =
FALSE )
{
- $this->arguments = new Console_ArgumentParser();
+ $this->arguments = new CLI_ArgumentParser();
foreach( $shortcuts as $key => $value )
$this->arguments->addShortCut( $key, $value );
$this->arguments->parseArguments( $fallBackOnEmptyPair );
=======================================
--- /branches/0.8.1/src/CLI/ArgumentParser.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/CLI/ArgumentParser.php Thu May 28 07:05:53 2015 UTC
@@ -31,7 +31,7 @@
* @category cmClasses
* @package Console
* @extends ADT_List_Dictionary
- * @uses Console_RequestReceiver
+ * @uses CLI_RequestReceiver
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -39,7 +39,7 @@
* @since 11.01.2006
* @version $Id$
*/
-class Console_ArgumentParser extends ADT_List_Dictionary
+class CLI_ArgumentParser extends ADT_List_Dictionary
{
/** @var array shortcuts Associative Array of Shortcuts */
private $shortcuts = array();
@@ -53,7 +53,7 @@
*/
public function parseArguments( $fallBackOnEmptyPair = FALSE )
{
- $request = new Console_RequestReceiver( $fallBackOnEmptyPair );
+ $request = new CLI_RequestReceiver( $fallBackOnEmptyPair );
$arguments = $request->getAll();
$script = key( array_slice( $arguments, 0, 1 ) );
# $this->set( "__file", __FILE__ );
=======================================
--- /branches/0.8.1/src/CLI/Command/ArgumentParser.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/CLI/Command/ArgumentParser.php Thu May 28 07:05:53
2015 UTC
@@ -35,7 +35,7 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Console_Command_ArgumentParser
+class CLI_Command_ArgumentParser
{
const STATUS_START = 0;
const STATUS_READ_OPTION_KEY = 1;
=======================================
--- /branches/0.8.1/src/CLI/Command/Program.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/CLI/Command/Program.php Thu May 28 07:05:53 2015 UTC
@@ -30,14 +30,14 @@
* @category cmClasses
* @package Console.Command
* @abstract
- * @uses Console_Command_ArgumentParser
+ * @uses CLI_Command_ArgumentParser
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-abstract class Console_Command_Program
+abstract class CLI_Command_Program
{
/** @var array $arguments Map of given Arguments */
protected $arguments = NULL;
@@ -74,7 +74,7 @@
*/
public function __construct( $options, $shortcuts, $numberArguments = 0 )
{
- $this->parser = new Console_Command_ArgumentParser(); // load
Argument Parser
+ $this->parser = new CLI_Command_ArgumentParser(); // load Argument
Parser
$this->parser->setNumberOfMandatoryArguments( $numberArguments ); //
set minimum Number of Arguments //
$this->parser->setPossibleOptions( $options ); // set Map of
Options and Patterns
$this->parser->setShortcuts( $shortcuts ); // set Map of
Shortcuts for Options
=======================================
--- /branches/0.8.1/src/CLI/Downloader.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/CLI/Downloader.php Thu May 28 07:05:53 2015 UTC
@@ -42,7 +42,7 @@
* @version $Id$
* @see
http://curl.haxx.se/libcurl/c/curl_easy_setopt.html
*/
-class Console_Downloader
+class CLI_Downloader
{
/** @var int $fileSize Length of File to download, extracted from
Response Headers */
protected $fileSize = 0;
@@ -213,7 +213,7 @@
$this->redirected = TRUE;
if( $this->templateRedirect )
printf( $this->templateRedirect, $content );
- $loader = new Console_Downloader();
+ $loader = new CLI_Downloader();
$loader->downloadUrl( $content, dirname( $this->fileUri ) );
}
if( preg_match( "@^Content-Length$@i", $header ) ) // Header is
Content-Length
=======================================
***Additional files exist in this changeset.***
--- /branches/0.8.1/src/Alg/Math/Formula.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Formula.php Thu May 28 07:05:53 2015 UTC
@@ -35,7 +35,7 @@
* @link
http://code.google.com/p/cmclasses/
* @version $Id$
*/
-class Math_Formula
+class Alg_Math_Formula
{
/** @var string $name Formular Name (default 'f') */
protected $name = "f";
=======================================
--- /branches/0.8.1/src/Alg/Math/FormulaProduct.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/FormulaProduct.php Thu May 28 07:05:53
2015 UTC
@@ -37,25 +37,25 @@
* @since 24.04.2006
* @version $Id$
*/
-class Math_FormulaProduct
+class Alg_Math_FormulaProduct
{
- /** @var Math_Formula $formula Formula */
+ /** @var Alg_Math_Formula $formula Formula */
protected $formula;
- /** @var Math_CompactInterval $interval Interval */
+ /** @var Alg_Math_CompactInterval $interval Interval */
protected $interval;
/**
* Constructor.
* @access public
* @param Math_Formula $formula Formula within Product
* @param Math_CompactInterval $interval Interval of Product
* @return void
*/
public function __construct( $formula, $interval )
{
- if( !is_a( $formula, 'Math_Formula' ) )
+ if( !is_a( $formula, 'Alg_Math_Formula' ) )
throw new InvalidArgumentException( 'No Formula Object given.' );
- if( !is_a( $interval, 'Math_CompactInterval' ) )
+ if( !is_a( $interval, 'Alg_Math_CompactInterval' ) )
throw new InvalidArgumentException( 'No Interval Object given.' );
$this->formula = $formula;
$this->interval = $interval;
@@ -37,25 +37,25 @@
* Constructor.
* @access public
- * @param Math_Formula $formula Formula within Product
- * @param Math_CompactInterval $interval Interval of Product
+ * @param Alg_Math_Formula $formula Formula within Product
+ * @param Alg_Math_CompactInterval $interval Interval of Product
* @return void
*/
=======================================
--- /branches/0.8.1/src/Alg/Math/FormulaSum.php Sat May 23 06:45:51 2015 UTC
+++ /branches/0.8.1/src/Alg/Math/FormulaSum.php Thu May 28 07:05:53 2015 UTC
@@ -37,30 +37,30 @@
* @since 24.04.2006
* @version $Id$
*/
-class Math_FormulaSum
+class Alg_Math_FormulaSum
{
- /** @var Math_Formula $formula Formula */
+ /** @var Alg_Math_Formula $formula Formula */
protected $formula;
- /** @var Math_CompactInterval $interval Interval */
+ /** @var Alg_Math_CompactInterval $interval Interval */
protected $interval;
/**
* Constructor.
* @access public
* @param Math_Formula $formula Formula within Sum
* @param Math_CompactInterval $interval Interval of Sum
* @return void
*/
public function __construct( $formula, $interval )
{
- if( !is_a( $formula, 'Math_Formula' ) )
+ if( !is_a( $formula, 'Alg_Math_Formula' ) )
throw new InvalidArgumentException( 'No Formula Object given.' );
- if( !is_a( $interval, 'Math_CompactInterval' ) )
+ if( !is_a( $interval, 'Alg_Math_CompactInterval' ) )
throw new InvalidArgumentException( 'No Interval Object given.' );
$this->formula = $formula;
$this->interval = $interval;
}
-
+
/**
* Calculates Sum of given Formula within given compact Interval and
Parameters.
* @access public
=======================================
--- /branches/0.8.1/src/Alg/Math/Geometry/Circle.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Geometry/Circle.php Thu May 28 07:05:53
2015 UTC
@@ -36,7 +36,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Geometry_Circle
+class Alg_Math_Geometry_Circle
{
protected $radius;
=======================================
--- /branches/0.8.1/src/Alg/Math/Geometry/Point.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Geometry/Point.php Thu May 28 07:05:53
2015 UTC
@@ -36,7 +36,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Geometry_Point
+class Alg_Math_Geometry_Point
{
protected $x;
protected $y;
=======================================
--- /branches/0.8.1/src/Alg/Math/Geometry/Rectangle.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Geometry/Rectangle.php Thu May 28 07:05:53
2015 UTC
@@ -29,7 +29,7 @@
* ...
* @category cmClasses
* @package Math.Geometry
- * @uses Math_Geometry_Triangle
+ * @uses Alg_Math_Geometry_Triangle
* @author Christian Würker <
christia...@ceusmedia.de>
* @copyright 2007-2012 Christian Würker
* @license
http://www.gnu.org/licenses/gpl-3.0.txt GPL 3
@@ -37,7 +37,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Geometry_Rectangle
+class Alg_Math_Geometry_Rectangle
{
public function __construct( $a, $b )
{
@@ -57,7 +57,7 @@
public function diagonal()
{
- $t = new Math_Geometry_Triangle();
+ $t = new Alg_Math_Geometry_Triangle();
$c = $t->pythagoras( $this->a, $this->b );
return $c;
}
=======================================
--- /branches/0.8.1/src/Alg/Math/Geometry/Square.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Geometry/Square.php Thu May 28 07:05:53
2015 UTC
@@ -36,7 +36,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Geometry_Square
+class Alg_Math_Geometry_Square
{
public function __construct( $a )
{
=======================================
--- /branches/0.8.1/src/Alg/Math/Geometry/Triangle.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/Geometry/Triangle.php Thu May 28 07:05:53
2015 UTC
@@ -36,7 +36,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_Geometry_Triangle
+class Alg_Math_Geometry_Triangle
{
public function pythagoras( $a = NULL, $b = NULL, $c = NULL )
{
=======================================
--- /branches/0.8.1/src/Alg/Math/NaturalNumbers.php Sat May 23 06:45:51
2015 UTC
+++ /branches/0.8.1/src/Alg/Math/NaturalNumbers.php Thu May 28 07:05:53
2015 UTC
@@ -34,7 +34,7 @@
* @version $Id$
* @todo Code Documentation
*/
-class Math_NaturalNumbers
+class Alg_Math_NaturalNumbers
{
public function abs( $number )
{
@@ -37,30 +37,30 @@
* Constructor.
* @access public
- * @param Math_Formula $formula Formula within Sum
- * @param Math_CompactInterval $interval Interval of Sum
+ * @param Alg_Math_Formula $formula Formula within Sum
+ * @param Alg_Math_CompactInterval $interval Interval of Sum
* @return void
*/
=======================================